[![Build Status - master](https://travis-ci.org/BhallaLab/moose-core.svg?branch=master)](https://travis-ci.org/BhallaLab/moose-core) | [![PyPI version](https://badge.fury.io/py/pymoose.svg)](https://badge.fury.io/py/pymoose) 

This is the core computational engine of [MOOSE simulator](https://github.com/BhallaLab/moose). This repository contains
C++ codebase and python interface called `pymoose`. For more details about MOOSE simulator, visit https://moose.ncbs.res.in .

# Installation

This repository is sufficient for using MOOSE as a python module. We provide python package via `pip`.

    $ pip install pymoose --user 

To install `nightly` build:

    $ pip install pymoose --user --pre --upgrde
    
Have a look at examples, tutorials and demo here https://github.com/BhallaLab/moose-examples.

# Build 

To build `pymoose`, follow instructions given here at https://github.com/BhallaLab/moose-core/blob/master/INSTALL.md 
